==> onnc-bench-1.3.0.tar.gz: onnc-bench-1.3.0/onnc/bench/cli/message.py <==
# exceptions
msgNotinONNCBenchDir = 'Fatal error: your current working path({}) is not an ONNC bench folder.'
msgInvalidONNCApiKey = 'Fatal error: the key({}) is not valid.'
msgBenchExists = 'Fatal error: destination path {} already exists and is not an empty directory.'
msgDeployExists = 'Fatal error: destination path {} already exists and is not an empty directory.'
msgBenchNotExists = 'Fatal error: source path {} does not exist.'
msgONNCApiKeyEmpty = 'Fatal error: unable to find ONNC api-key in LICENSE.txt\nplease use the command `onnc-login` to setup your api-key'
msgTemplateListNotFound = 'Fatal error: unable to find template list at({})'
msgWorkspaceUploadFailure = 'Fatal error: failed to upload model. (ws_id: {})'
msgWorkspaceCompileFailure = 'Fatal error: failed to compile model. (ws_id: {})'
msgWorkspaceDownloadFailure = 'Fatal error: failed to download model. (ws_id: {})'

# user message
msgUserRegister = ['Please visit the following website to create a new account:',
                   'https://shop.skymizer.com']
msgUserEnterKey = 'Please enter your API key'
msgONNCCreateDone = ['[{}] Create directory structure,',
                     '[{}] Generate scripts',
                     '[{}] Done']
msgLoginDone = 'Your api key was written to LICENSE.txt'

msgComile = ['[Upload model]',
             '[Upload calibration samples]',
             '[Calibration and compilation]',
             '[Download deployment]',
             '[Done]'
             ]

msgCreateInferDone = ['[Download {} example]',
                      '[Create `{}`]',
                      '[Done]'
                      ]
msgDeployDone = ['[Copy results]',
                 '[Done]']

==> onnc-bench-1.4.0.tar.gz: onnc-bench-1.4.0/onnc/bench/cli/message.py <==
# exceptions
msgNotinONNCBenchDir = 'Fatal error: your current working path({}) is not an ONNC bench folder.'
msgInvalidONNCApiKey = 'Fatal error: the key({}) is not valid.'
msgBenchExists = 'Fatal error: destination path {} already exists and is not an empty directory.'
msgDeployExists = 'Fatal error: destination path {} already exists and is not an empty directory.'
msgBenchNotExists = 'Fatal error: source path {} does not exist.'
msgONNCApiKeyEmpty = 'Fatal error: unable to find ONNC api-key in LICENSE.txt\nplease use the command `onnc-login` to setup your api-key'
msgTemplateListNotFound = 'Fatal error: unable to find template list at({})'
msgWorkspaceUploadFailure = 'Fatal error: failed to upload model. (ws_id: {})'
msgWorkspaceCompileFailure = 'Fatal error: failed to compile model. (ws_id: {})'
msgWorkspaceDownloadFailure = 'Fatal error: failed to download model. (ws_id: {})'

# user message
msgUserRegister = 'Please register your account and get API key from https://shop.skymizer.com/register'
msgUserEnterKey = 'Please enter your API key'
msgONNCCreateDone = ['[{}] Create directory structure,',
                     '[{}] Generate scripts',
                     '[{}] Done']
msgLoginDone = 'Your api key was written to LICENSE.txt'

msgComile = ['[Upload model]',
             '[Upload calibration samples]',
             '[Calibration and compilation]',
             '[Download deployment]',
             '[Done]'
             ]

msgCreateInferDone = ['[Download {} example]',
                      '[Create `{}`]',
                      '[Done]'
                      ]
msgDeployDone = ['[Copy results]',
                 '[Done]']
